@@ -31,6 +31,7 @@ from .literals import (
     JQStateType,
     JQStatusType,
     LogDriverType,
+    OrchestrationTypeType,
     PlatformCapabilityType,
     ResourceTypeType,
     RetryActionType,
@@ -48,6 +49,7 @@ __all__ = (
     "ArrayPropertiesTypeDef",
     "NetworkInterfaceTypeDef",
     "CancelJobRequestRequestTypeDef",
+    "EksConfigurationTypeDef",
     "UpdatePolicyTypeDef",
     "ComputeEnvironmentOrderTypeDef",
     "Ec2ConfigurationTypeDef",
@@ -73,6 +75,14 @@ __all__ = (
     "DescribeSchedulingPoliciesRequestRequestTypeDef",
     "DeviceTypeDef",
     "EFSAuthorizationConfigTypeDef",
+    "EksAttemptContainerDetailTypeDef",
+    "EksContainerEnvironmentVariableTypeDef",
+    "EksContainerResourceRequirementsTypeDef",
+    "EksContainerSecurityContextTypeDef",
+    "EksContainerVolumeMountTypeDef",
+    "EksEmptyDirTypeDef",
+    "EksHostPathTypeDef",
+    "EksSecretTypeDef",
     "EvaluateOnExitTypeDef",
     "ShareAttributesTypeDef",
     "HostTypeDef",
@@ -109,6 +119,11 @@ __all__ = (
     "DescribeJobQueuesRequestDescribeJobQueuesPaginateTypeDef",
     "ListSchedulingPoliciesRequestListSchedulingPoliciesPaginateTypeDef",
     "EFSVolumeConfigurationTypeDef",
+    "EksAttemptDetailTypeDef",
+    "EksContainerOverrideTypeDef",
+    "EksContainerDetailTypeDef",
+    "EksContainerTypeDef",
+    "EksVolumeTypeDef",
     "RetryStrategyTypeDef",
     "FairsharePolicyTypeDef",
     "JobSummaryTypeDef",
@@ -123,6 +138,9 @@ __all__ = (
     "UpdateComputeEnvironmentRequestRequestTypeDef",
     "NodePropertyOverrideTypeDef",
     "VolumeTypeDef",
+    "EksPodPropertiesOverrideTypeDef",
+    "EksPodPropertiesDetailTypeDef",
+    "EksPodPropertiesTypeDef",
     "CreateSchedulingPolicyRequestRequestTypeDef",
     "SchedulingPolicyDetailTypeDef",
     "UpdateSchedulingPolicyRequestRequestTypeDef",
@@ -131,9 +149,12 @@ __all__ = (
     "NodeOverridesTypeDef",
     "ContainerDetailTypeDef",
     "ContainerPropertiesTypeDef",
+    "EksPropertiesOverrideTypeDef",
+    "EksPropertiesDetailTypeDef",
+    "EksPropertiesTypeDef",
     "DescribeSchedulingPoliciesResponseTypeDef",
-    "SubmitJobRequestRequestTypeDef",
     "NodeRangePropertyTypeDef",
+    "SubmitJobRequestRequestTypeDef",
     "NodePropertiesTypeDef",
     "JobDefinitionTypeDef",
     "JobDetailTypeDef",
@@ -187,6 +208,14 @@ CancelJobRequestRequestTypeDef = TypedDict(
     },
 )
 
+EksConfigurationTypeDef = TypedDict(
+    "EksConfigurationTypeDef",
+    {
+        "eksClusterArn": str,
+        "kubernetesNamespace": str,
+    },
+)
+
 UpdatePolicyTypeDef = TypedDict(
     "UpdatePolicyTypeDef",
     {
@@ -214,6 +243,7 @@ _OptionalEc2ConfigurationTypeDef = TypedDict(
     "_OptionalEc2ConfigurationTypeDef",
     {
         "imageIdOverride": str,
+        "imageKubernetesVersion": str,
     },
     total=False,
 )
@@ -426,6 +456,103 @@ EFSAuthorizationConfigTypeDef = TypedDict(
     total=False,
 )
 
+EksAttemptContainerDetailTypeDef = TypedDict(
+    "EksAttemptContainerDetailTypeDef",
+    {
+        "exitCode": int,
+        "reason": str,
+    },
+    total=False,
+)
+
+_RequiredEksContainerEnvironmentVariableTypeDef = TypedDict(
+    "_RequiredEksContainerEnvironmentVariableTypeDef",
+    {
+        "name": str,
+    },
+)
+_OptionalEksContainerEnvironmentVariableTypeDef = TypedDict(
+    "_OptionalEksContainerEnvironmentVariableTypeDef",
+    {
+        "value": str,
+    },
+    total=False,
+)
+
+
+class EksContainerEnvironmentVariableTypeDef(
+    _RequiredEksContainerEnvironmentVariableTypeDef, _OptionalEksContainerEnvironmentVariableTypeDef
+):
+    pass
+
+
+EksContainerResourceRequirementsTypeDef = TypedDict(
+    "EksContainerResourceRequirementsTypeDef",
+    {
+        "limits": Dict[str, str],
+        "requests": Dict[str, str],
+    },
+    total=False,
+)
+
+EksContainerSecurityContextTypeDef = TypedDict(
+    "EksContainerSecurityContextTypeDef",
+    {
+        "runAsUser": int,
+        "runAsGroup": int,
+        "privileged": bool,
+        "readOnlyRootFilesystem": bool,
+        "runAsNonRoot": bool,
+    },
+    total=False,
+)
+
+EksContainerVolumeMountTypeDef = TypedDict(
+    "EksContainerVolumeMountTypeDef",
+    {
+        "name": str,
+        "mountPath": str,
+        "readOnly": bool,
+    },
+    total=False,
+)
+
+EksEmptyDirTypeDef = TypedDict(
+    "EksEmptyDirTypeDef",
+    {
+        "medium": str,
+        "sizeLimit": str,
+    },
+    total=False,
+)
+
+EksHostPathTypeDef = TypedDict(
+    "EksHostPathTypeDef",
+    {
+        "path": str,
+    },
+    total=False,
+)
+
+_RequiredEksSecretTypeDef = TypedDict(
+    "_RequiredEksSecretTypeDef",
+    {
+        "secretName": str,
+    },
+)
+_OptionalEksSecretTypeDef = TypedDict(
+    "_OptionalEksSecretTypeDef",
+    {
+        "optional": bool,
+    },
+    total=False,
+)
+
+
+class EksSecretTypeDef(_RequiredEksSecretTypeDef, _OptionalEksSecretTypeDef):
+    pass
+
+
 _RequiredEvaluateOnExitTypeDef = TypedDict(
     "_RequiredEvaluateOnExitTypeDef",
     {
@@ -899,6 +1026,96 @@ class EFSVolumeConfigurationTypeDef(
     pass
 
 
+EksAttemptDetailTypeDef = TypedDict(
+    "EksAttemptDetailTypeDef",
+    {
+        "containers": List[EksAttemptContainerDetailTypeDef],
+        "podName": str,
+        "nodeName": str,
+        "startedAt": int,
+        "stoppedAt": int,
+        "statusReason": str,
+    },
+    total=False,
+)
+
+EksContainerOverrideTypeDef = TypedDict(
+    "EksContainerOverrideTypeDef",
+    {
+        "image": str,
+        "command": Sequence[str],
+        "args": Sequence[str],
+        "env": Sequence[EksContainerEnvironmentVariableTypeDef],
+        "resources": EksContainerResourceRequirementsTypeDef,
+    },
+    total=False,
+)
+
+EksContainerDetailTypeDef = TypedDict(
+    "EksContainerDetailTypeDef",
+    {
+        "name": str,
+        "image": str,
+        "imagePullPolicy": str,
+        "command": List[str],
+        "args": List[str],
+        "env": List[EksContainerEnvironmentVariableTypeDef],
+        "resources": EksContainerResourceRequirementsTypeDef,
+        "exitCode": int,
+        "reason": str,
+        "volumeMounts": List[EksContainerVolumeMountTypeDef],
+        "securityContext": EksContainerSecurityContextTypeDef,
+    },
+    total=False,
+)
+
+_RequiredEksContainerTypeDef = TypedDict(
+    "_RequiredEksContainerTypeDef",
+    {
+        "image": str,
+    },
+)
+_OptionalEksContainerTypeDef = TypedDict(
+    "_OptionalEksContainerTypeDef",
+    {
+        "name": str,
+        "imagePullPolicy": str,
+        "command": List[str],
+        "args": List[str],
+        "env": List[EksContainerEnvironmentVariableTypeDef],
+        "resources": EksContainerResourceRequirementsTypeDef,
+        "volumeMounts": List[EksContainerVolumeMountTypeDef],
+        "securityContext": EksContainerSecurityContextTypeDef,
+    },
+    total=False,
+)
+
+
+class EksContainerTypeDef(_RequiredEksContainerTypeDef, _OptionalEksContainerTypeDef):
+    pass
+
+
+_RequiredEksVolumeTypeDef = TypedDict(
+    "_RequiredEksVolumeTypeDef",
+    {
+        "name": str,
+    },
+)
+_OptionalEksVolumeTypeDef = TypedDict(
+    "_OptionalEksVolumeTypeDef",
+    {
+        "hostPath": EksHostPathTypeDef,
+        "emptyDir": EksEmptyDirTypeDef,
+        "secret": EksSecretTypeDef,
+    },
+    total=False,
+)
+
+
+class EksVolumeTypeDef(_RequiredEksVolumeTypeDef, _OptionalEksVolumeTypeDef):
+    pass
+
+
 RetryStrategyTypeDef = TypedDict(
     "RetryStrategyTypeDef",
     {
@@ -1036,6 +1253,9 @@ _OptionalComputeEnvironmentDetailTypeDef = TypedDict(
         "computeResources": ComputeResourceTypeDef,
         "serviceRole": str,
         "updatePolicy": UpdatePolicyTypeDef,
+        "eksConfiguration": EksConfigurationTypeDef,
+        "containerOrchestrationType": OrchestrationTypeType,
+        "uuid": str,
     },
     total=False,
 )
@@ -1062,6 +1282,7 @@ _OptionalCreateComputeEnvironmentRequestRequestTypeDef = TypedDict(
         "computeResources": ComputeResourceTypeDef,
         "serviceRole": str,
         "tags": Mapping[str, str],
+        "eksConfiguration": EksConfigurationTypeDef,
     },
     total=False,
 )
@@ -1131,6 +1352,40 @@ VolumeTypeDef = TypedDict(
     total=False,
 )
 
+EksPodPropertiesOverrideTypeDef = TypedDict(
+    "EksPodPropertiesOverrideTypeDef",
+    {
+        "containers": Sequence[EksContainerOverrideTypeDef],
+    },
+    total=False,
+)
+
+EksPodPropertiesDetailTypeDef = TypedDict(
+    "EksPodPropertiesDetailTypeDef",
+    {
+        "serviceAccountName": str,
+        "hostNetwork": bool,
+        "dnsPolicy": str,
+        "containers": List[EksContainerDetailTypeDef],
+        "volumes": List[EksVolumeTypeDef],
+        "podName": str,
+        "nodeName": str,
+    },
+    total=False,
+)
+
+EksPodPropertiesTypeDef = TypedDict(
+    "EksPodPropertiesTypeDef",
+    {
+        "serviceAccountName": str,
+        "hostNetwork": bool,
+        "dnsPolicy": str,
+        "containers": List[EksContainerTypeDef],
+        "volumes": List[EksVolumeTypeDef],
+    },
+    total=False,
+)
+
 _RequiredCreateSchedulingPolicyRequestRequestTypeDef = TypedDict(
     "_RequiredCreateSchedulingPolicyRequestRequestTypeDef",
     {
@@ -1286,6 +1541,30 @@ ContainerPropertiesTypeDef = TypedDict(
     total=False,
 )
 
+EksPropertiesOverrideTypeDef = TypedDict(
+    "EksPropertiesOverrideTypeDef",
+    {
+        "podProperties": EksPodPropertiesOverrideTypeDef,
+    },
+    total=False,
+)
+
+EksPropertiesDetailTypeDef = TypedDict(
+    "EksPropertiesDetailTypeDef",
+    {
+        "podProperties": EksPodPropertiesDetailTypeDef,
+    },
+    total=False,
+)
+
+EksPropertiesTypeDef = TypedDict(
+    "EksPropertiesTypeDef",
+    {
+        "podProperties": EksPodPropertiesTypeDef,
+    },
+    total=False,
+)
+
 DescribeSchedulingPoliciesResponseTypeDef = TypedDict(
     "DescribeSchedulingPoliciesResponseTypeDef",
     {
@@ -1294,6 +1573,27 @@ DescribeSchedulingPoliciesResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredNodeRangePropertyTypeDef = TypedDict(
+    "_RequiredNodeRangePropertyTypeDef",
+    {
+        "targetNodes": str,
+    },
+)
+_OptionalNodeRangePropertyTypeDef = TypedDict(
+    "_OptionalNodeRangePropertyTypeDef",
+    {
+        "container": ContainerPropertiesTypeDef,
+    },
+    total=False,
+)
+
+
+class NodeRangePropertyTypeDef(
+    _RequiredNodeRangePropertyTypeDef, _OptionalNodeRangePropertyTypeDef
+):
+    pass
+
+
 _RequiredSubmitJobRequestRequestTypeDef = TypedDict(
     "_RequiredSubmitJobRequestRequestTypeDef",
     {
@@ -1316,6 +1616,7 @@ _OptionalSubmitJobRequestRequestTypeDef = TypedDict(
         "propagateTags": bool,
         "timeout": JobTimeoutTypeDef,
         "tags": Mapping[str, str],
+        "eksPropertiesOverride": EksPropertiesOverrideTypeDef,
     },
     total=False,
 )
@@ -1327,27 +1628,6 @@ class SubmitJobRequestRequestTypeDef(
     pass
 
 
-_RequiredNodeRangePropertyTypeDef = TypedDict(
-    "_RequiredNodeRangePropertyTypeDef",
-    {
-        "targetNodes": str,
-    },
-)
-_OptionalNodeRangePropertyTypeDef = TypedDict(
-    "_OptionalNodeRangePropertyTypeDef",
-    {
-        "container": ContainerPropertiesTypeDef,
-    },
-    total=False,
-)
-
-
-class NodeRangePropertyTypeDef(
-    _RequiredNodeRangePropertyTypeDef, _OptionalNodeRangePropertyTypeDef
-):
-    pass
-
-
 NodePropertiesTypeDef = TypedDict(
     "NodePropertiesTypeDef",
     {
@@ -1379,6 +1659,8 @@ _OptionalJobDefinitionTypeDef = TypedDict(
         "tags": Dict[str, str],
         "propagateTags": bool,
         "platformCapabilities": List[PlatformCapabilityType],
+        "eksProperties": EksPropertiesTypeDef,
+        "containerOrchestrationType": OrchestrationTypeType,
     },
     total=False,
 )
@@ -1420,6 +1702,8 @@ _OptionalJobDetailTypeDef = TypedDict(
         "tags": Dict[str, str],
         "propagateTags": bool,
         "platformCapabilities": List[PlatformCapabilityType],
+        "eksProperties": EksPropertiesDetailTypeDef,
+        "eksAttempts": List[EksAttemptDetailTypeDef],
     },
     total=False,
 )
@@ -1448,6 +1732,7 @@ _OptionalRegisterJobDefinitionRequestRequestTypeDef = TypedDict(
         "timeout": JobTimeoutTypeDef,
         "tags": Mapping[str, str],
         "platformCapabilities": Sequence[PlatformCapabilityType],
+        "eksProperties": EksPropertiesTypeDef,
     },
     total=False,
 )
